agentle.agents.whatsapp.providers.base.whatsapp\_provider
=========================================================

.. automodule:: agentle.agents.whatsapp.providers.base.whatsapp_provider

   
   .. rubric:: Functions

   .. autosummary::
   
      abstractmethod
   
   .. rubric:: Classes

   .. autosummary::
   
      DownloadedMedia
      Protocol
      WhatsAppContact
      WhatsAppMediaMessage
      WhatsAppProvider
      WhatsAppSession
      WhatsAppTextMessage
      WhatsAppWebhookPayload
   